dnl 	have the vtf3 dirs specified
AC_DEFUN([WITH_VTF3_DIR],
[
    AH_TEMPLATE(HAVE_VTF3, [], [defined if vtf3 library is to be used])

    AC_ARG_WITH([vtf3],
        AC_HELP_STRING([--with-vtf3],[use given vtf3 dir]),
            [vtf3_dir=$withval],
            [vtf3_dir=$PWD/../vtf/])
    AC_CACHE_CHECK([which vtf3 dir to use],
        [vtf3_dir],
        [vtf3_dir=])

    AC_ARG_WITH([vtf3-lib-dir],
        AC_HELP_STRING([--with-vtf3-lib-dir],[use given vtf3 lib dir]),
            [vtf3_lib_dir=$withval],
            [vtf3_lib_dir=$vtf3_dir])
    AC_CACHE_CHECK([which vtf3 lib dir to use],
        [vtf3_lib_dir],
        [vtf3_lib_dir=])

    AC_ARG_WITH([vtf3-include-dir],
        AC_HELP_STRING([--with-vtf3-include-dir],[use given vtf3 include dir]),
            [vtf3_include_dir=$withval],
            [vtf3_include_dir=$vtf3_dir])
    AC_CACHE_CHECK([which vtf3 include dir to use],
        [vtf3_include_dir],
        [vtf3_include_dir=])

    if test x"$vtf3_lib_dir" = x; then
        AC_MSG_NOTICE([no vtf3_lib_dir specified!])
    else
        VTF3_LIB_DIR=$vtf3_lib_dir
    fi

    if test x"$vtf3_include_dir" != x; then
        VTF3_INCLUDE_DIR=$vtf3_include_dir
        VTF3_INCLUDE_LINE=-I$vtf3_include_dir
    fi

    if test x"$vtf3_lib_dir" != x  ; then
        VTF3_LIB_LINE="-L$vtf3_lib_dir -lvtf3"
    fi

    if test -e $VTF3_INCLUDE_DIR/vtf3.h; then

        AC_MSG_NOTICE([   found $VTF3_INCLUDE_DIR/vtf3.h])

    else

        AC_MSG_NOTICE([   cannot find $VTF3_INCLUDE_DIR/vtf3.h])
		# exit 1;
    fi

    if test -e $VTF3_LIB_DIR/libvtf3.a; then

        AC_MSG_NOTICE([   found $VTF3_LIB_DIR/libvtf3.a])

    elif test -e $VTF3_LIB_DIR/libvtf3.so; then

        AC_MSG_NOTICE([   found $VTF3_LIB_DIR/libvtf3.so])

    else

        AC_MSG_NOTICE([   cannot find $VTF3_LIB_DIR/libvtf3.a or $VTF3_LIB_DIR/libvtf3.so])
		# exit 1;
    fi


    if test -e $VTF3_INCLUDE_DIR/vtf3.h && \
	    test -e $VTF3_LIB_DIR/libvtf3.a -o -e $VTF3_LIB_DIR/libvtf3.so ; then

        AC_MSG_NOTICE([   using VTF3... yes])
	    AC_DEFINE(HAVE_VTF3)

		have_vtf3="yes"

    else
        AC_MSG_NOTICE([   using VTF3... no])
		VTF3_LIB_DIR=""
		VTF3_LIB_LINE=""
		VTF3_INCLUDE_DIR=""
		VTF3_INCLUDE_LINE=""

		have_vtf3="no"
	fi

    AC_SUBST(VTF3_LIB_DIR)
    AC_SUBST(VTF3_LIB_LINE)
    AC_SUBST(VTF3_INCLUDE_DIR)
    AC_SUBST(VTF3_INCLUDE_LINE)
])

dnl 	switch on/off additonal debug output in otf lib
AC_DEFUN([WITH_DEBUG],
[
    AH_TEMPLATE(OTF_DEBUG, [], [switch on/off additonal debug checks in otf lib])

    AC_ARG_WITH([debug],
        AC_HELP_STRING([--with-debug],[additonal debug checks]),
            [debug=$withval],
            [debug=""])

    AC_CACHE_CHECK([debug],
        [debug],
        [debug=])

    if test "$debug" = yes; then
     AC_DEFINE(OTF_DEBUG)
    fi
])

dnl 	switch on/off additonal debug output in otf lib
AC_DEFUN([WITH_VERBOSE],
[
    AH_TEMPLATE(OTF_VERBOSE, [], [switch on/off verbose output in otf lib])

    AC_ARG_WITH([verbose],
        AC_HELP_STRING([--with-verbose],[additonal verbose output]),
            [verbose=$withval],
            [verbose=""])

    AC_CACHE_CHECK([verbose],
        [verbose],
        [verbose=])

    if test "$verbose" = yes; then
     AC_DEFINE(OTF_VERBOSE)
    fi
])

