/*
 This is part of the OTF library. Copyright by ZIH, TU Dresden 2005-2006.
 Authors: Andreas Knuepfer, Holger Brunst, Ronny Brendel, Thomas Kriebitzsch
*/

#ifndef OTF_COPYHANDLER_H
#define OTF_COPYHANDLER_H

#include <inttypes.h>

/* *** Definition handler *** ************************************* */

int OTF_CopyHandler_DefinitionComment( void* firsthandlerarg, uint32_t streamid,
	const char* comment );
	
int OTF_CopyHandler_DefTimerResolution( void* firsthandlerarg,
	uint32_t streamid, uint64_t ticksPerSecond );

int OTF_CopyHandler_DefProcess( void* firsthandlerarg, uint32_t streamid,
	uint32_t deftoken, const char* name, uint32_t parent );

int OTF_CopyHandler_DefProcessGroup( void* firsthandlerarg, uint32_t streamid,
	uint32_t deftoken, const char* name, uint32_t n, uint32_t* array );

int OTF_CopyHandler_DefFunction( void* firsthandlerarg, uint32_t streamid,
	uint32_t deftoken, const char* name, uint32_t group, uint32_t scltoken );

int OTF_CopyHandler_DefFunctionGroup( void* firsthandlerarg, uint32_t streamid,
	uint32_t deftoken, const char* name );

int OTF_DefCollectiveOperation( void* firsthandlerarg, uint32_t streamid,
	uint32_t deftoken, const char* name, uint32_t type );

int OTF_CopyHandler_DefCounter( void* firsthandlerarg, uint32_t streamid,
	uint32_t deftoken, const char* name, uint32_t properties, 
	uint32_t countergroup, const char* unit );

int OTF_CopyHandler_DefCounterGroup( void* firsthandlerarg, uint32_t streamid,
	uint32_t deftoken, const char* name );

int OTF_CopyHandler_DefScl( void* firsthandlerarg, uint32_t streamid,
	uint32_t deftoken, uint32_t sclfile, uint32_t sclline );

int OTF_CopyHandler_DefSclFile( void* firsthandlerarg, uint32_t streamid,
	uint32_t deftoken, const char* filename );

int OTF_CopyHandler_DefVersion( void* firsthandlerarg, uint32_t streamid,
	uint8_t major, uint8_t minor, uint8_t sub, const char* string );

int OTF_CopyHandler_DefCreator( void* firsthandlerarg, uint32_t streamid,
	const char* creator );

/* *** Event handler *** ****************************************** */

int OTF_CopyHandler_EventComment( void* firsthandlerarg, uint64_t time, 
	const char* comment );

int OTF_CopyHandler_Counter( void* firsthandlerarg, uint64_t time, 
	uint32_t process, uint32_t counter_token, uint64_t value );

int OTF_CopyHandler_Enter( void* firsthandlerarg, uint64_t time, 
	uint32_t statetoken, uint32_t cpuid, uint32_t scltoken );

int OTF_CopyHandler_Leave( void* firsthandlerarg, uint64_t time, 
	uint32_t statetoken, uint32_t cpuid, uint32_t scltoken );

int OTF_CopyHandler_CollectiveOperation( void* firsthandlerarg, uint64_t time, 
    uint32_t process, uint32_t functionToken, uint32_t communicator, 
    uint32_t rootprocess, uint32_t sent, uint32_t received, 
    uint64_t duration, uint32_t scltoken );

int OTF_CopyHandler_RecvMsg( void* firsthandlerarg, uint64_t time, 
	uint32_t receiver, uint32_t sender, uint32_t communicator, 
	uint32_t msgtype, uint32_t msglength,
	uint32_t scltoken );

int OTF_CopyHandler_SendMsg( void* firsthandlerarg, uint64_t time, 
	uint32_t sender, uint32_t receiver, uint32_t communicator, 
	uint32_t msgtype, uint32_t msglength, uint32_t scltoken );

int OTF_CopyHandler_BeginProcess( void* firsthandlerarg, uint64_t time,
	uint32_t process );

int OTF_CopyHandler_EndProcess( void* firsthandlerarg, uint64_t time,
	uint32_t process );

/* Handlers for OTF snapshot records *************************************** */


int OTF_CopyHandler_SnapshotComment( void* firsthandlerarg, uint64_t time,
	uint32_t process, const char* comment );
	
int OTF_CopyHandler_EnterSnapshot( void *firsthandlerarg, uint64_t time,
	uint64_t originaltime, uint32_t function, uint32_t process,
	uint32_t source );

int OTF_CopyHandler_SendSnapshot( void *firsthandlerarg, uint64_t time,
	uint64_t originaltime, uint32_t sender, uint32_t receiver,
	uint32_t procGroup, uint32_t tag, uint32_t source );


/* *** Summary handler *** ****************************************** */

int OTF_CopyHandler_SummaryComment( void* firsthandlerarg, uint64_t time,
	uint32_t process, const char* comment );
	
int OTF_CopyHandler_FunctionSummary( void* firsthandlerarg, 
	uint64_t time, uint32_t function, uint32_t process, 
	uint64_t count, uint64_t excltime, uint64_t incltime );

int OTF_CopyHandler_FunctionGroupSummary( void* firsthandlerarg, 
	uint64_t time, uint32_t functiongroup, uint32_t process,  
	uint64_t count, uint64_t excltime, uint64_t incltime );

int OTF_CopyHandler_MessageSummary( void* userData, uint64_t time,
	uint32_t process, uint32_t peer, uint32_t comm, uint32_t type,
	uint64_t sentNumber, uint64_t receivedNumber, uint64_t sentBytes,
	uint64_t receivedBytes );

/*int OTF_CopyHandler_CounterSummary( void* firsthandlerarg, 
	uint64_t time, uint32_t process,  
	uint32_t counter, uint64_t value );

int OTF_CopyHandler_CollOpSummary( void* firsthandlerarg, 
	uint64_t time, uint32_t process, uint32_t root,  
	uint64_t bytes_sent, uint64_t bytes_recved );
*/

#endif /* OTF_COPYHANDLER_H */
